diff lisp/efs/dired.el @ 138:6608ceec7cf8 r20-2b3

Import from CVS: tag r20-2b3
author cvs
date Mon, 13 Aug 2007 09:31:46 +0200
parents 7d55a9ba150c
children 1856695b1fa9
line wrap: on
line diff
--- a/lisp/efs/dired.el	Mon Aug 13 09:31:13 2007 +0200
+++ b/lisp/efs/dired.el	Mon Aug 13 09:31:46 2007 +0200
@@ -422,9 +422,9 @@
   "*File names matching these regexp may be omitted (buffer-local).
 This only has effect when the subdirectory is in omission mode.
 To make omission mode the default, set `dired-omit-files' to t.
-This only has effect when `dired-omit-files-p' is t.
+This only has effect when `dired-omit-files' is t.
 See also `dired-omit-extensions'.")
-(make-variable-buffer-local 'dired-omit-files-regexp)
+(make-variable-buffer-local 'dired-omit-regexps)
 
 (defvar dired-filename-re-ext "\\..+$"   ; start from the first dot. last dot?
   "*Defines what is the extension of a file name.
@@ -1563,7 +1563,7 @@
       (run-hooks 'dired-after-readin-hook)
       ;; I put omit-expunge after the dired-after-readin-hook
       ;; in case that hook marks files. Does this make sense? Also, users
-      ;; might want to set dired-omit-files-p in some incredibly clever
+      ;; might want to set dired-omit-files in some incredibly clever
       ;; way depending on the contents of the directory... I don't know...
       (if dired-omit-files
 	  (dired-omit-expunge nil t))
@@ -5273,7 +5273,7 @@
 
 (defun dired-omit-toggle (&optional arg)
   "Toggle between displaying and omitting files matching
-`dired-omit-files-regexp' in the current subdirectory.
+`dired-omit-regexps' in the current subdirectory.
 With a positive prefix, omits files in the entire tree dired buffer.
 With a negative prefix, forces all files in the tree dired buffer to be
 displayed."
@@ -5317,7 +5317,7 @@
 
 (defun dired-omit-expunge (&optional regexp full-buffer)
   ;; Hides all unmarked files matching REGEXP.
   ;; If REGEXP is nil or not specified, uses `dired-omit-files-regexp',
   ;; and also omits filenames ending in `dired-omit-extensions'.
   ;; If REGEXP is the empty string, this function is a no-op.
   (let ((omit-re (or regexp (dired-omit-regexp)))
@@ -5317,7 +5317,7 @@
 (defun dired-omit-expunge (&optional regexp full-buffer)
   ;; Hides all unmarked files matching REGEXP.
-  ;; If REGEXP is nil or not specified, uses `dired-omit-files-regexp',
+  ;; If REGEXP is nil or not specified, uses `dired-omit-regexps',
   ;; and also omits filenames ending in `dired-omit-extensions'.
   ;; If REGEXP is the empty string, this function is a no-op.